#[repr(transparent)]pub struct SidebarSection {
inner: TypedObjectRef<SidebarSection, ()>,
phantom: PhantomData<()>,
}Expand description
A list of items in the same section of the sidebar.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SidebarSection, ()>phantom: PhantomData<()>Implementations
Sourceimpl SidebarSection
impl SidebarSection
Sourcepub fn model(&self) -> <OnceCell<ListModel> as Property>::Value
pub fn model(&self) -> <OnceCell<ListModel> as Property>::Value
The source model of this section.
Sourcepub fn display_name(&self) -> <PhantomData<String> as Property>::Value
pub fn display_name(&self) -> <PhantomData<String> as Property>::Value
The display name of this section.
Sourcepub fn set_is_expanded<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_is_expanded<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this section is expanded.
Sourcepub fn has_notifications(&self) -> <Cell<bool> as Property>::Value
pub fn has_notifications(&self) -> <Cell<bool> as Property>::Value
Whether any of the rooms in this section have unread notifications.
Sourcepub fn notification_count(&self) -> <Cell<u64> as Property>::Value
pub fn notification_count(&self) -> <Cell<u64> as Property>::Value
Total number of unread notifications over all the rooms in this section.
Sourcepub fn is_read(&self) -> <Cell<bool> as Property>::Value
pub fn is_read(&self) -> <Cell<bool> as Property>::Value
Whether all the messages of all the rooms in this section are read.
Sourcepub fn highlight(&self) -> <Cell<HighlightFlags> as Property>::Value
pub fn highlight(&self) -> <Cell<HighlightFlags> as Property>::Value
The highlight state of the section.
Sourcepub fn connect_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the model property
Sourcepub fn connect_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the name property
Sourcepub fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name property
Sourcepub fn connect_is_empty_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_empty_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-empty property
Sourcepub fn connect_is_expanded_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_expanded_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-expanded property
Sourcepub fn connect_has_notifications_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_has_notifications_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the has-notifications property
Sourcepub fn connect_notification_count_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_notification_count_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the notification-count property
Sourcepub fn connect_is_read_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_read_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-read property
Sourcepub fn connect_highlight_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_highlight_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the highlight property
Sourcepub fn notify_model(&self)
pub fn notify_model(&self)
Notify listeners of a change in the model property
Sourcepub fn notify_name(&self)
pub fn notify_name(&self)
Notify listeners of a change in the name property
Sourcepub fn notify_display_name(&self)
pub fn notify_display_name(&self)
Notify listeners of a change in the display-name property
Sourcepub fn notify_is_empty(&self)
pub fn notify_is_empty(&self)
Notify listeners of a change in the is-empty property
Sourcepub fn notify_is_expanded(&self)
pub fn notify_is_expanded(&self)
Notify listeners of a change in the is-expanded property
Sourcepub fn notify_has_notifications(&self)
pub fn notify_has_notifications(&self)
Notify listeners of a change in the has-notifications property
Sourcepub fn notify_notification_count(&self)
pub fn notify_notification_count(&self)
Notify listeners of a change in the notification-count property
Sourcepub fn notify_is_read(&self)
pub fn notify_is_read(&self)
Notify listeners of a change in the is-read property
Sourcepub fn notify_highlight(&self)
pub fn notify_highlight(&self)
Notify listeners of a change in the highlight property
Sourceimpl SidebarSection
impl SidebarSection
Sourcepub fn new(name: SidebarSectionName, model: &impl IsA<ListModel>) -> Self
pub fn new(name: SidebarSectionName, model: &impl IsA<ListModel>) -> Self
Constructs a new SidebarSection with the given name and source model.
Sourcepub(crate) fn visible_for_room_category(
&self,
source_category: Option<RoomCategory>,
) -> bool
pub(crate) fn visible_for_room_category( &self, source_category: Option<RoomCategory>, ) -> bool
Whether this section should be shown for the drag-n-drop of a room with the given category.